/**
 * Copyright (c) Baidu Inc. All rights reserved.
 *
 * This source code is licensed under the MIT license.
 * See LICENSE file in the project root for license information.
 *
 * @file 获取 element 的 transition 控制对象
 */

var evalArgs = require('../runtime/eval-args');
var findMethod = require('../runtime/find-method');
var handleError = require('../util/handle-error');
var NodeType = require('./node-type');

/**
 * 获取 element 的 transition 控制对象
 *
 * @param {Object} element 元素
 * @return {Object?}
 */
function elementGetTransition(element) {
    var directive = element.aNode.directives.transition;
    var owner = element.owner;

    if (element.nodeType === NodeType.CMPT) {
        var cmptGivenTransition = element.source && element.source.directives.transition;
        if (cmptGivenTransition) {
            directive = cmptGivenTransition;
        }
        else {
            owner = element;
        }
    }

    var transition;
    if (directive && owner) {
        transition = findMethod(owner, directive.value.name);

        if (typeof transition === 'function') {
            try {
                transition = transition.apply(
                    owner,
                    evalArgs(directive.value.args, element.scope, owner)
                );
            }
            catch (e) {
                handleError(e, owner, 'transitionCreate')
            }
        }
    }

    return transition || element.transition;
}

exports = module.exports = elementGetTransition;
